==> hs-vector-space-0.5.7.tbz: lib/vector-space-0.5.7/register.sh <==
#!/bin/sh

echo 'name: vector-space
version: 0.5.7
license: BSD3
copyright: (c) 2008 by Conal Elliott
maintainer: conal@conal.net
stability: experimental
homepage: http://haskell.org/haskellwiki/vector-space
package-url: http://code.haskell.org/vector-space
description: /vector-space/ provides classes and generic operations for vector
             spaces and affine spaces.  It also defines a type of infinite towers
             of generalized derivatives.  A generalized derivative is a linear
             transformation rather than one of the common concrete representations
             (scalars, vectors, matrices, ...).
             .
             /Warning/: this package depends on type families working fairly well,
             and requires ghc version at least 6.9.
             .
             Project wiki page: <http://haskell.org/haskellwiki/vector-space>
             .
             &#169; 2008 by Conal Elliott; BSD3 license.
category: math
author: Conal Elliott
exposed: True
exposed-modules: Data.AdditiveGroup Data.VectorSpace Data.Basis
                 Data.LinearMap Data.Maclaurin Data.Derivative Data.Cross
                 Data.AffineSpace Data.NumInstances
hidden-modules:
import-dirs: /usr/local/lib/vector-space-0.5.7/ghc-6.10.4
library-dirs: /usr/local/lib/vector-space-0.5.7/ghc-6.10.4
hs-libraries: HSvector-space-0.5.7
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: MemoTrie-0.4.7 base-4.1.0.0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/vector-space-0.5.7/html/vector-space.haddock
haddock-html: /usr/local/share/doc/vector-space-0.5.7/html' | /usr/local/bin/ghc-pkg update -

==> hs-vector-space-0.7.1.tbz: lib/vector-space-0.7.1/register.sh <==
#!/bin/sh

echo 'name: vector-space
version: 0.7.1
license: BSD3
copyright: (c) 2008 by Conal Elliott
maintainer: conal@conal.net
stability: experimental
homepage: http://haskell.org/haskellwiki/vector-space
package-url: http://code.haskell.org/vector-space
description: /vector-space/ provides classes and generic operations for vector
             spaces and affine spaces.  It also defines a type of infinite towers
             of generalized derivatives.  A generalized derivative is a linear
             transformation rather than one of the common concrete representations
             (scalars, vectors, matrices, ...).
             .
             /Warning/: this package depends on type families working fairly well,
             and requires ghc version at least 6.9.
             .
             Project wiki page: <http://haskell.org/haskellwiki/vector-space>
             .
             &#169; 2008-2010 by Conal Elliott; BSD3 license.
category: math
author: Conal Elliott
exposed: True
exposed-modules: Data.AdditiveGroup Data.VectorSpace Data.Basis
                 Data.LinearMap Data.Maclaurin Data.Derivative Data.Cross
                 Data.AffineSpace Data.NumInstances
hidden-modules:
import-dirs: /usr/local/lib/vector-space-0.7.1/ghc-6.10.4
library-dirs: /usr/local/lib/vector-space-0.7.1/ghc-6.10.4
              /usr/local/lib
hs-libraries: HSvector-space-0.7.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: Boolean-0.0.1 MemoTrie-0.4.7 base-4.1.0.0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/vector-space-0.7.1/html/vector-space.haddock
haddock-html: /usr/local/share/doc/vector-space-0.7.1/html' | /usr/local/bin/ghc-pkg update -
